@@ -1,38 +1,39 @@
+# frozen_string_literal: false
 #
-#   nop.rb - 
-#   	$Release Version: 0.9.5$
-#   	$Revision: 14912 $
+#   nop.rb -
+#   	$Release Version: 0.9.6$
+#   	$Revision: 53141 $
 #   	by Keiju ISHITSUKA(keiju@ruby-lang.org)
 #
 # --
 #
-#   
 #
+#
+# :stopdoc:
 module IRB
   module ExtendCommand
     class Nop
-      
-      @RCS_ID='-$Id: nop.rb 14912 2008-01-06 15:49:38Z akr $-'
+
 
       def self.execute(conf, *opts)
-	command = new(conf)
-	command.execute(*opts)
+        command = new(conf)
+        command.execute(*opts)
       end
 
       def initialize(conf)
-	@irb_context = conf
+        @irb_context = conf
       end
 
       attr_reader :irb_context
 
       def irb
-	@irb_context.irb
+        @irb_context.irb
       end
 
       def execute(*opts)
-	#nop
+        #nop
       end
     end
   end
 end
-
+# :startdoc:
